@@ -1,5 +1,6 @@
 from .chat import ChatManager
 from .api import API
+from functools import wraps
 
 
 class HyperChat:
@@ -16,10 +17,14 @@ class HyperChat:
         self.chat_manager = ChatManager(self, self.host, self.token, self.api.lista_canales(), ssl_active=self.ssl)
 
     def route(self, command):
-        def decorator(func):
+        def decorator(f):
+            @wraps(f)
             def wrapper(*args, **kwargs):
-                func(args, kwargs)
+                f(args, kwargs)
+
             self.rutas[command] = wrapper
+            return wrapper
+
         return decorator
 
     def send(self, request, mensaje):
